@@ -1,7 +1,7 @@
 /*
  * This file is part of sidplayfp, a console SID player.
  *
- * Copyright 2011-2023 Leandro Nini
+ * Copyright 2011-2024 Leandro Nini
  * Copyright 2000-2001 Simon White
  *
  * This program is free software; you can redistribute it and/or modify
@@ -119,7 +119,13 @@ void IniConfig::clear()
 
     emulation_s.bias            = 0.5;
     emulation_s.filterCurve6581 = 0.5;
+#ifdef FEAT_FILTER_RANGE
+    emulation_s.filterRange6581 = 0.5;
+#endif
     emulation_s.filterCurve8580 = 0.5;
+#ifdef FEAT_CW_STRENGTH
+    emulation_s.combinedWaveformsStrength = SidConfig::AVERAGE;
+#endif
     emulation_s.powerOnDelay = -1;
     emulation_s.samplingMethod = SidConfig::RESAMPLE_INTERPOLATE;
     emulation_s.fastSampling = false;
@@ -322,8 +328,8 @@ void IniConfig::readSidplay2(iniHandler &ini)
 #if !defined _WIN32
     if (sidplay2_s.database.empty())
     {
-        SID_STRING buffer(PKGDATADIR);
-        buffer.append("Songlengths.txt");
+        SID_STRING buffer(utils::getDataPath());
+        buffer.append(SEPARATOR).append(DIR_NAME).append(SEPARATOR).append("Songlengths.txt");
         if (::access(buffer.c_str(), R_OK) == 0)
             sidplay2_s.database.assign(buffer);
     }
@@ -426,8 +432,26 @@ void IniConfig::readEmulation(iniHandler &ini)
 
     readDouble(ini, TEXT("FilterBias"), emulation_s.bias);
     readDouble(ini, TEXT("FilterCurve6581"), emulation_s.filterCurve6581);
+#ifdef FEAT_FILTER_RANGE
+    readDouble(ini, TEXT("filterRange6581"), emulation_s.filterRange6581);
+#endif
     readDouble(ini, TEXT("FilterCurve8580"), emulation_s.filterCurve8580);
 
+#ifdef FEAT_CW_STRENGTH
+    {
+        SID_STRING str = readString(ini, TEXT("CombinedWaveforms"));
+        if (!str.empty())
+        {
+            if (str.compare(TEXT("AVERAGE")) == 0)
+                emulation_s.combinedWaveformsStrength = SidConfig::AVERAGE;
+            else if (str.compare(TEXT("WEAK")) == 0)
+                emulation_s.combinedWaveformsStrength = SidConfig::WEAK;
+            else if (str.compare(TEXT("STRONG")) == 0)
+                emulation_s.combinedWaveformsStrength = SidConfig::STRONG;
+        }
+    }
+#endif
+
     readInt(ini, TEXT("PowerOnDelay"), emulation_s.powerOnDelay);
 
     {
@@ -457,22 +481,22 @@ public:
 void createDir(const SID_STRING& path)
 {
 #ifndef _WIN32
-	DIR *dir = opendir(path.c_str());
+    DIR *dir = opendir(path.c_str());
     if (dir)
-	{
-		closedir(dir);
-	}
-	else if (errno == ENOENT)
-	{
+    {
+        closedir(dir);
+    }
+    else if (errno == ENOENT)
+    {
         if (mkdir(path.c_str(), 0755) < 0)
         {
             throw iniError(strerror(errno));
         }
     }
-	else
-	{
-		throw iniError(strerror(errno));
-	}
+    else
+    {
+        throw iniError(strerror(errno));
+    }
 #else
     if (GetFileAttributes(path.c_str()) == INVALID_FILE_ATTRIBUTES)
     {
@@ -505,12 +529,12 @@ SID_STRING getConfigPath()
     debug(TEXT("Config path: "), configPath.c_str());
 
     // Make sure the config path exists
-	createDir(configPath);
+    createDir(configPath);
 
     configPath.append(SEPARATOR).append(DIR_NAME);
 
     // Make sure the app config path exists
-	createDir(configPath);
+    createDir(configPath);
 
     configPath.append(SEPARATOR).append(FILE_NAME);
 
