@@ -82,7 +82,13 @@ public:
         bool          filter;
         double        bias;
         double        filterCurve6581;
+#ifdef FEAT_FILTER_RANGE
+        double        filterRange6581;
+#endif
         double        filterCurve8580;
+#ifdef FEAT_CW_STRENGTH
+        SidConfig::sid_cw_t combinedWaveformsStrength;
+#endif
         int           powerOnDelay;
         SidConfig::sampling_method_t  samplingMethod;
         bool          fastSampling;
