@@ -163,7 +163,7 @@ bool iniHandler::setSection(const TCHAR *section)
 const TCHAR *iniHandler::getValue(const TCHAR *key) const
 {
     keys_t::const_iterator keyIt = std::find_if((*curSection).second.begin(), (*curSection).second.end(), compare<stringPair_t>(key));
-    return (keyIt != (*curSection).second.end()) ? keyIt->second.c_str() : 0;
+    return (keyIt != (*curSection).second.end()) ? keyIt->second.c_str() : nullptr;
 }
 
 void iniHandler::addSection(const TCHAR *section)
@@ -193,11 +193,11 @@ bool iniHandler::write(const TCHAR *fName)
         return false;
     }
 
-    for (sections_t::iterator section = sections.begin(); section != sections.end(); ++section)
+    for (auto & section : sections)
     {
-        iniFile << "[" << (*section).first << "]" << std::endl;
+        iniFile << "[" << section.first << "]" << std::endl;
 
-        for (keys_t::iterator entry = (*section).second.begin(); entry != (*section).second.end(); ++entry)
+        for (keys_t::iterator entry = section.second.begin(); entry != section.second.end(); ++entry)
         {
             const SID_STRING key = (*entry).first;
             if (!key.empty())
