@@ -33,7 +33,7 @@ using std::cout;
 using std::cerr;
 using std::endl;
 
-#include <stdlib.h>
+#include <cstdlib>
 
 #ifdef HAVE_UNISTD_H
 #  include <unistd.h>
@@ -142,6 +142,7 @@ static const filter_map_t filterRangeMap =
     { "Figge Wasberger (Fegolhuzz)",         0.25 },
     { "Fred Gray",                           0.18 },
     { "Geir Tjelta",                         0.5 },
+    { "Geoff Follin",                        0.85 },
     { "Georg Feil",                          0.2 },
     { "Glenn Rune Gallefoss",                0.2 },
     { "Graham Jarvis & Rob Hartshorne",      0.25 },
@@ -323,12 +324,12 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
     m_name(name),
     m_tune(nullptr),
     m_state(playerStopped),
-    m_outfile(NULL),
+    m_outfile(nullptr),
     m_filename(""),
     m_fcurve(-1.0),
     m_quietLevel(0),
+    songlengthDB(SLDB_NONE),
     m_cpudebug(false),
-    newSonglengthDB(false),
     m_autofilter(false)
 {
 #ifdef FEAT_REGS_DUMP_SID
@@ -336,7 +337,7 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
 #endif
     // Other defaults
     m_filter.enabled = true;
-    m_driver.device  = NULL;
+    m_driver.device  = nullptr;
     m_driver.sid     = EMU_RESIDFP;
     m_timer.start    = 0;
     m_timer.length   = 0; // FOREVER
@@ -433,7 +434,7 @@ std::string ConsolePlayer::getFileName(const SidTuneInfo *tuneInfo, const char*
 {
     std::string title;
 
-    if (m_outfile != NULL)
+    if (m_outfile != nullptr)
     {
         title = m_outfile;
         if (title.compare("-") != 0
@@ -617,6 +618,12 @@ bool ConsolePlayer::createSidEmu (SIDEMUS emu, const SidTuneInfo *tuneInfo)
                     cerr << "Recommended filter range: " << frange << endl;
             }
 
+            if ((frange < 0.0) || (frange > 1.0))
+            {
+                cerr << "Invalid 6581 filter range: " << frange << endl;
+                exit(EXIT_FAILURE);
+            }
+
             if (m_verboseLevel)
                 cerr << "6581 filter range: " << frange << endl;
             rs->filter6581Range(frange);
@@ -637,6 +644,12 @@ bool ConsolePlayer::createSidEmu (SIDEMUS emu, const SidTuneInfo *tuneInfo)
                 fcurve = m_fcurve;
             }
 
+            if ((fcurve < 0.0) || (fcurve > 1.0))
+            {
+                cerr << "Invalid 6581 filter curve: " << fcurve << endl;
+                exit(EXIT_FAILURE);
+            }
+
             if (m_verboseLevel)
                 cerr << "6581 filter curve: " << fcurve << endl;
             rs->filter6581Curve(fcurve);
@@ -648,6 +661,12 @@ bool ConsolePlayer::createSidEmu (SIDEMUS emu, const SidTuneInfo *tuneInfo)
                 fcurve = m_fcurve;
             }
 
+            if ((fcurve < 0.0) || (fcurve > 1.0))
+            {
+                cerr << "Invalid 8580 filter curve: " << fcurve << endl;
+                exit(EXIT_FAILURE);
+            }
+
             if (m_verboseLevel)
                 cerr << "8580 filter curve: " << fcurve << endl;
             rs->filter8580Curve(fcurve);
@@ -799,7 +818,7 @@ bool ConsolePlayer::open (void)
     if (!m_timer.valid)
     {
 #ifdef FEAT_NEW_SONLEGTH_DB
-        const int_least32_t length = newSonglengthDB ? m_database.lengthMs(m_tune) : (m_database.length(m_tune) * 1000);
+        const int_least32_t length = songlengthDB == SLDB_MD5 ? m_database.lengthMs(m_tune) : (m_database.length(m_tune) * 1000);
 #else
         const int_least32_t length = m_database.length(m_tune) * 1000;
 #endif
@@ -909,7 +928,12 @@ bool ConsolePlayer::play()
     switch (m_state)
     {
     case playerRunning:
-        m_driver.selected->write(retSize);
+        if (!m_driver.selected->write(retSize))
+        {
+            cerr << m_driver.selected->getErrorString();
+            m_state = playerError;
+            return false;
+        }
         // fall-through
     case playerPaused:
         // Check for a keypress (approx 250ms rate, but really depends
