@@ -1,7 +1,7 @@
 /*
  * This file is part of sidplayfp, a console SID player.
  *
- * Copyright 2021 Leandro Nini
+ * Copyright 2021-2024 Leandro Nini
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,4 +39,9 @@
 #  define FEAT_DB_WCHAR_OPEN
 #endif
 
+#if LIBSIDPLAYFP_VERSION_MAJ > 2 || (LIBSIDPLAYFP_VERSION_MAJ == 2 && LIBSIDPLAYFP_VERSION_MIN >= 7)
+#  define FEAT_FILTER_RANGE
+#  define FEAT_CW_STRENGTH
+#endif
+
 #endif
